Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Client ¶
type Client interface {
// GetPod returns current pod data.
GetPod(ctx context.Context, namespace, name string) (*corev1.Pod, error)
// GetFailureDomainTags returns current failure domain for pod
GetFailureDomainTags(ctx context.Context, pod *corev1.Pod) ([]string, error)
}
Client is an interface for client to Kubernetes API.
type ServiceProvider ¶
ServiceProvider is responsible for providing services that should be registered in Consul discovery service.
func (*ServiceProvider) Get ¶
func (p *ServiceProvider) Get(ctx context.Context) ([]consul.ServiceInstance, error)
Get returns slice of services that are configured to be registered in Consul discovery service.
Click to show internal directories.
Click to hide internal directories.